@@ -87,6 +87,12 @@ pub enum Keyword {
 
     /// `xor`
     Xor,
+
+    /// `maybe`
+    Maybe,
+
+    /// `else`
+    Else,
 }
 impl Keyword {
     /// Returns the string representation of this keyword.
@@ -119,6 +125,8 @@ impl Keyword {
             Keyword::Try => "try",
             Keyword::When => "when",
             Keyword::Xor => "xor",
+            Keyword::Maybe => "maybe",
+            Keyword::Else => "else",
         }
     }
 }
@@ -189,6 +197,9 @@ pub enum Symbol {
     /// `??`
     DoubleQuestion,
 
+    /// `?=`
+    MaybeMatch,
+
     /// `!`
     Not,
 
@@ -294,6 +305,7 @@ impl Symbol {
             Symbol::GreaterEq => ">=",
             Symbol::Less => "<",
             Symbol::LessEq => "=<",
+            Symbol::MaybeMatch => "?=",
         }
     }
 }
